isLastPage property
A boolean that indicates if the last page of data has been reached. This is used to stop triggering onLoadMore and to show the 'All caught up!' message.
Implementation
final bool isLastPage;
A boolean that indicates if the last page of data has been reached. This is used to stop triggering onLoadMore and to show the 'All caught up!' message.
final bool isLastPage;